@@ -8,14 +8,13 @@
 
 
 from dataclasses import dataclass
-from typing import Type
+from typing import Type, Any
+import json
 
 from http_tools.http_server_connector import HttpServerConnector
 from init_helpers.dict_to_dataclass import dict_to_dataclass, T
 from init_helpers.custom_json import custom_dumps
 
-from detector_connector.detector_kafka_connector import DetectionAnalyzeResultType
-
 DetectorSettingsType = Type[T]
 
 
@@ -35,10 +34,10 @@ class DetectorHttpConnector:
         self._connector = HttpServerConnector(config, context)
         self.detector_settings_type = detector_settings_type
 
-    async def get_settings(self, stream_url: str, token: str) -> T:
+    async def get_settings(self, rtsp_url: str, token: str) -> T:
         payload = {
                 "token": token,
-                "stream_url": stream_url
+                "rtsp_url": rtsp_url
         }
         answer = await self._connector.get("/settings/get",
                                            url_query=payload,
@@ -46,21 +45,21 @@ class DetectorHttpConnector:
 
         return dict_to_dataclass(answer["result"], self.detector_settings_type)
 
-    async def set_settings(self, detector_settings: T, token: str) -> T:
+    async def set_settings(self, detector_settings: T, token: str) -> dict[str, Any]:
         payload = {"token": token}
-        payload.update(custom_dumps(detector_settings))
-        answer = await self._connector.post_json("/settings/correct",
+        payload.update(json.loads(custom_dumps(detector_settings)))
+        answer = await self._connector.post_json("/settings/set",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return dict_to_dataclass(answer["result"], self.detector_settings_type)
+        return answer["result"]
 
-    async def autotune_settings(self, detection: T, token: str) -> T:
+    async def autotune_settings(self, detection: T, token: str) -> dict[str, Any]:
         payload = {"token": token}
-        payload.update({"detection": custom_dumps(detection)})
-        answer = await self._connector.post_json("/settings/correct",
+        payload.update({"detection": json.loads(custom_dumps(detection))})
+        answer = await self._connector.post_json("/settings/autotune",
                                                  payload=payload,
                                                  headers=self._construct_headers())
-        return dict_to_dataclass(answer["result"], self.detector_settings_type)
+        return answer["result"]
 
     def _construct_headers(self) -> dict[str, str]:
         return {"server_name": self.context.project_name}
